Module queries

Module queries 

Queries needed for polling, updating and exposing tasks.

Functions

ack_tasks
Ack multiple tasks, given a worker
fetch_next
Fetch the next batch of tasks from the sqlite backend
keep_alive
Send a keep-alive signal to the database to indicate that the worker is still active
lock_tasks
Lock multiple tasks, given a worker
push_tasks
Push a batch of tasks into the database
reenqueue_abandoned
Re-enqueue tasks that were being processed by dying a worker
reenqueue_orphaned
Re-enqueue tasks that were being processed by dead workers
register_worker
Register a new worker in the database

Type Aliases

AckPayload
Represents the result of a SqliteTask execution