reenqueue_orphaned

Function reenqueue_orphaned 

pub async fn reenqueue_orphaned<'a, E>(
    executor: E,
    dead_for: i64,
    queue: &str,
    filter: &WorkerFilter,
) -> Result<u64, Error>
where E: Executor<'a, Database = Sqlite>,
Re-enqueue tasks that were being processed by dead workers

A worker that has not sent a keep-alive signal within the heartbeat duration is considered dead