Module shared

Module shared 

Structs

SharedFetcher
SharedSqliteStorage
Shared Sqlite storage backend that can be used across multiple workers

Enums

SharedSqliteError
Errors that can occur when creating a shared Sqlite storage backend