pub struct SqliteStorageFactory { /* private fields */ }Expand description
Shared Sqlite storage backend that can be used across multiple workers
Implementations
Sourceimpl SqliteStorageFactory
impl SqliteStorageFactory
Sourcepub fn pool(&self) -> &SqlitePool
pub fn pool(&self) -> &SqlitePool
Get a reference to the underlying Sqlite connection pool
Sourceimpl SqliteStorageFactory
impl SqliteStorageFactory
Sourcepub fn new(url: &str) -> SqliteStorageFactory
pub fn new(url: &str) -> SqliteStorageFactory
Create a new shared Sqlite storage backend with the given database URL and codec
Sourcepub fn new_with_pool_options(
url: &str,
options: PoolOptions<Sqlite>,
) -> SqliteStorageFactory
pub fn new_with_pool_options( url: &str, options: PoolOptions<Sqlite>, ) -> SqliteStorageFactory
Create a new shared Sqlite storage backend with the given database URL and pool options