SqliteStorage

Struct SqliteStorage 

pub struct SqliteStorage<Args> { /* private fields */ }
SqliteStorage is a storage backend for apalis using sqlite as the database.

It supports both standard polling and event-driven (hooked) storage mechanisms.

Features

FeatureStatusDescription
BackendSupports storage and retrieval of tasks
TaskSinkAbility to push new tasks
SerializationSerialization support for arguments
WorkflowFlexible enough to support workflows
Web InterfaceExpose a web interface for monitoring tasks
FetchByIdAllow fetching a task by its ID
RegisterWorkerAllow registering a worker with the backend
BackendFactoryShare one connection across multiple workers via SqliteStorageFactory
WaitForCompletionWait for tasks to complete without blocking
ResumeByIdResume a task by its ID
ResumeAbandonedResume abandoned tasks
ListWorkersList all workers registered with the backend
ListTasksList all tasks in the backend

Key: ✅ : Supported | ⚠️ : Not implemented | ❌ : Not Supported | ❗ Limited support

Tests:
Backend
#[tokio::main]
async fn main() {
    // let mut backend = /* snip */;
    
    async fn task(task: u32, worker: WorkerContext) {
        // Do some work 
    }
    let worker = WorkerBuilder::new("backend-test")
        .backend(backend)
        .build(task);
    let _ = worker.stream().take(1).collect::<Vec<_>>().await;
}
TaskSink
#[tokio::main]
async fn main() {
    // let mut backend = /* snip */;
    
    backend.push(42).await.unwrap();

    async fn task(task: u32, worker: WorkerContext) {
        worker.stop().unwrap();
    }
    let worker = WorkerBuilder::new("task-sink-test")
        .backend(backend)
        .build(task);
    worker.run().await.unwrap();
}
Serialization
#[tokio::main]
async fn main() {
    // let mut backend = /* snip */;
    
   fn assert_codec<B: BackendConfig + WireFormatBackend>(backend: B) 
   where
       B::Codec: Codec<B::Args, Compact=Vec<u8>>,
   {
   }
   assert_codec(backend);
}
Workflow
#[tokio::main]
async fn main() {
    // let mut backend = /* snip */;
    
    backend.push(42).await.unwrap();

    async fn task1(task: u32, worker: WorkerContext) -> u32 {
        task + 99 
    }
    async fn task2(task: u32, worker: WorkerContext) -> u32 {
        task + 1 
    }
    async fn task3(task: u32, worker: WorkerContext) {
        assert_eq!(task, 142);
        worker.stop().unwrap();
    }
    let workflow = SteppedFlow::new("test-workflow")
       .and_then(task1)
       .and_then(task2)
       .and_then(task3);
    let worker = WorkerBuilder::new("workflow-test")
        .backend(backend)
        .build(workflow);
    worker.run().await.unwrap();
}
WebUI
#[tokio::main]
async fn main() {
    // let mut backend = /* snip */;
    
    fn assert_web_ui<B: Expose<u32, Durable>>(backend: B) {};
    assert_web_ui(backend);
}
WaitForCompletion
#[tokio::main]
async fn main() {
    // let mut backend = /* snip */;
    
    fn assert_wait_for_completion<B: WaitForCompletion<u32> + Backend>(backend: B) {};
    assert_wait_for_completion(backend);
}

Implementations

Source

impl SqliteStorage<()>

pub fn connect_with_callback( url: &str, ) -> Result<(SqlitePool, HookCallbackListener), Error>

Connects to a database returning a pool and listener

pub async fn setup(pool: &SqlitePool) -> Result<(), Error>

Perform migrations for storage

pub fn migrations() -> Migrator

Get sqlite migrations without running them

Source

impl<T> SqliteStorage<T>

pub fn new(pool: &SqlitePool) -> SqliteStorage<T>

Create a new SqliteStorage

pub fn with_config(self, config: Config) -> SqliteStorage<T>

Create a new SqliteStorage with a custom configuration

pub fn with_callback( self, callback: HookCallbackListener, ) -> PollWith<Self, StreamStrategy<HookCallbackListener>>

Attach a callback to an instance

pub fn pool(&self) -> &SqlitePool

Get the underlying pool