Queries needed for polling, updating and exposing tasks.
Functions
- ack_
tasks - Ack multiple tasks, given a worker
- fetch_
next - Fetch the next batch of tasks from the sqlite backend
- keep_
alive - Send a keep-alive signal to the database to indicate that the worker is still active
- lock_
tasks - Lock multiple tasks, given a worker
- push_
tasks - Push a batch of tasks into the database
- reenqueue_
abandoned - Re-enqueue tasks that were being processed by dying a worker
- reenqueue_
orphaned - Re-enqueue tasks that were being processed by dead workers
- register_
worker - Register a new worker in the database
Type Aliases
- AckPayload
- Represents the result of a
SqliteTaskexecution