pub struct SqliteStorage<Args> { /* private fields */ }Expand description
SqliteStorage is a storage backend for apalis using sqlite as the database.
It supports both standard polling and event-driven (hooked) storage mechanisms.
Features
| Feature | Status | Description |
|---|---|---|
Backend | ✅ | Supports storage and retrieval of tasks |
TaskSink | ✅ | Ability to push new tasks |
Serialization | ✅ | Serialization support for arguments |
Workflow | ✅ | Flexible enough to support workflows |
Web Interface | ✅ | Expose a web interface for monitoring tasks |
FetchById | ✅ | Allow fetching a task by its ID |
RegisterWorker | ✅ | Allow registering a worker with the backend |
BackendFactory | ✅ | Share one connection across multiple workers via SqliteStorageFactory |
WaitForCompletion | ✅ | Wait for tasks to complete without blocking |
ResumeById | ✅ | Resume a task by its ID |
ResumeAbandoned | ✅ | Resume abandoned tasks |
ListWorkers | ✅ | List all workers registered with the backend |
ListTasks | ✅ | List all tasks in the backend |
Key: ✅ : Supported | ⚠️ : Not implemented | ❌ : Not Supported | ❗ Limited support
Tests:
Backend
#[tokio::main]
async fn main() {
// let mut backend = /* snip */;
async fn task(task: u32, worker: WorkerContext) {
// Do some work
}
let worker = WorkerBuilder::new("backend-test")
.backend(backend)
.build(task);
let _ = worker.stream().take(1).collect::<Vec<_>>().await;
}
TaskSink
#[tokio::main]
async fn main() {
// let mut backend = /* snip */;
backend.push(42).await.unwrap();
async fn task(task: u32, worker: WorkerContext) {
worker.stop().unwrap();
}
let worker = WorkerBuilder::new("task-sink-test")
.backend(backend)
.build(task);
worker.run().await.unwrap();
}
Serialization
#[tokio::main]
async fn main() {
// let mut backend = /* snip */;
fn assert_codec<B: BackendConfig + WireFormatBackend>(backend: B)
where
B::Codec: Codec<B::Args, Compact=Vec<u8>>,
{
}
assert_codec(backend);
}
Workflow
#[tokio::main]
async fn main() {
// let mut backend = /* snip */;
backend.push(42).await.unwrap();
async fn task1(task: u32, worker: WorkerContext) -> u32 {
task + 99
}
async fn task2(task: u32, worker: WorkerContext) -> u32 {
task + 1
}
async fn task3(task: u32, worker: WorkerContext) {
assert_eq!(task, 142);
worker.stop().unwrap();
}
let workflow = SteppedFlow::new("test-workflow")
.and_then(task1)
.and_then(task2)
.and_then(task3);
let worker = WorkerBuilder::new("workflow-test")
.backend(backend)
.build(workflow);
worker.run().await.unwrap();
}
WebUI
#[tokio::main]
async fn main() {
// let mut backend = /* snip */;
fn assert_web_ui<B: Expose<u32, Durable>>(backend: B) {};
assert_web_ui(backend);
}
WaitForCompletion
#[tokio::main]
async fn main() {
// let mut backend = /* snip */;
fn assert_wait_for_completion<B: WaitForCompletion<u32> + Backend>(backend: B) {};
assert_wait_for_completion(backend);
}
Implementations
Sourceimpl SqliteStorage<()>
impl SqliteStorage<()>
Sourcepub fn connect_with_callback(
url: &str,
) -> Result<(SqlitePool, HookCallbackListener), Error>
pub fn connect_with_callback( url: &str, ) -> Result<(SqlitePool, HookCallbackListener), Error>
Connects to a database returning a pool and listener
Sourcepub fn migrations() -> Migrator
pub fn migrations() -> Migrator
Get sqlite migrations without running them
Sourceimpl<T> SqliteStorage<T>
impl<T> SqliteStorage<T>
Sourcepub fn new(pool: &SqlitePool) -> SqliteStorage<T>
pub fn new(pool: &SqlitePool) -> SqliteStorage<T>
Create a new SqliteStorage
Sourcepub fn with_config(self, config: Config) -> SqliteStorage<T>
pub fn with_config(self, config: Config) -> SqliteStorage<T>
Create a new SqliteStorage with a custom configuration
Sourcepub fn with_callback(
self,
callback: HookCallbackListener,
) -> PollWith<Self, StreamStrategy<HookCallbackListener>>
pub fn with_callback( self, callback: HookCallbackListener, ) -> PollWith<Self, StreamStrategy<HookCallbackListener>>
Attach a callback to an instance
Sourcepub fn pool(&self) -> &SqlitePool
pub fn pool(&self) -> &SqlitePool
Get the underlying pool